@@ -5,7 +5,7 @@ Zabbix::Check::Supervisor - Zabbix check for Supervisor service
 
 =head1 VERSION
 
-version 1.08
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -14,7 +14,7 @@ Zabbix check for Supervisor service
 	UserParameter=cpan.zabbix.check.supervisor.installed,/usr/bin/perl -MZabbix::Check::Supervisor -e_installed
 	UserParameter=cpan.zabbix.check.supervisor.running,/usr/bin/perl -MZabbix::Check::Supervisor -e_running
 	UserParameter=cpan.zabbix.check.supervisor.worker_discovery,/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_discovery
-	UserParameter=cpan.zabbix.check.supervisor.worker_status[*],/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_status $1
+	UserParameter=cpan.zabbix.check.supervisor.worker_status[*],/usr/bin/perl -MZabbix::Check::Supervisor -e_worker_status -- $1
 
 =head3 installed
 
@@ -49,7 +49,7 @@ BEGIN
 {
 	require Exporter;
 	# set the version for version checking
-	our $VERSION     = '1.08';
+	our $VERSION     = '1.10';
 	# Inherit from Exporter to export functions and variables
 	our @ISA         = qw(Exporter);
 	# Functions and variables which are exported by default
@@ -66,13 +66,17 @@ our ($supervisord) = whereisBin('supervisord');
 sub getStatuses
 {
 	return unless $supervisorctl;
-	my $result = {};
-	for (`$supervisorctl status 2>/dev/null`)
+	my $result = fileCache("all", 30, sub
 	{
-		chomp;
-		my ($name, $status) = /^(\S+)\s+(\S+)\s*/;
-		$result->{$name} = $status;
-	}
+		my $result = {};
+		for (`$supervisorctl status 2>/dev/null`)
+		{
+			chomp;
+			my ($name, $status) = /^(\S+)\s+(\S+)\s*/;
+			$result->{$name} = $status;
+		}
+		return $result;
+	});
 	return $result;
 }
 
@@ -107,15 +111,9 @@ sub _worker_status
 {
 	my ($name) = map(zbxDecode($_), @ARGV);
 	return unless $name;
-	my $nameS = shellmeta($name);
 	my $result = "";
-	my $line = `$supervisorctl status \"$nameS\" 2>/dev/null` if $supervisorctl;
-	if ($line)
-	{
-		chomp $line;
-		my ($name, $status) = $line =~/^(\S+)\s+(\S+)\s*/;
-		$result = $status if $status;
-	}
+	my $statuses = getStatuses();
+	$result = $statuses->{$name} if $statuses->{$name};
 	print $result;
 	return $result;	
 }
